@@ -8,10 +8,10 @@ from torch.utils.data import DataLoader
 import numpy as np
 import matplotlib.pyplot as plt
 
-def drawImage(img):
+def drawImage(img, scale=2):
     img = img.cpu().detach().clamp(min=0, max=1)
     if len(img.shape)==4 :
-        plt.figure(figsize=(img.shape[0]*1.2, 1.2))
+        plt.figure(figsize=(img.shape[0]*scale, scale))
         for i in range(img.shape[0]):
             plt.subplot(1,img.shape[0], i+1); plt.imshow(img[i].permute(1,2,0)); plt.xticks([]); plt.yticks([], interpolation='nearest');
         plt.show()
@@ -29,9 +29,11 @@ class Residual(nn.Module):
 class ConditionalResidual(nn.Module):
     def __init__(self, d_condition, d_x, window_size, scale_factor, groups=1):
         super().__init__()
-        self.conv = nn.ConvTrans2d(d_condition, d_x, window_size, groups=groups, stride=scale_factor, padding=window_size//2)
+        self.scale_factor=scale_factor
+        self.conv = nn.Conv2d(d_condition, d_x, 1, groups=1)
         
     def forward(self, x, condition):
+        condition = F.interpolate(condition, scale_factor=self.scale_factor, mode='bicubic')
         return x + self.conv(condition) 
 
 class Shuffle(nn.Module):
@@ -64,7 +66,7 @@ def ConvMixerOriginal(dim, depth, kernel_size=9, patch_size=7, n_classes=1000):
 		nn.Linear(dim, n_classes)
 	)
 
-def ConvNeXt(dim, kernel_size, dim_mult=4, groups=4):
+def ConvNeXt(dim, kernel_size, dim_mult=2, groups=2):
 	if groups == 1:
 		return Residual(nn.Sequential(
 					nn.Conv2d(dim, dim, kernel_size=kernel_size, padding=kernel_size//2, groups=dim//8),
@@ -103,7 +105,7 @@ class Tokenizer2d(nn.Module):
         self.eps = 1e-6
         self.enc = nn.Sequential(
             nn.Conv2d(d_in, dim, kernel_size=patch_size, stride=patch_size),
-            * [ConvNeXt(dim=dim, kernel_size=5) for i in range(depth) ],
+            * [ConvNeXt(dim=dim, kernel_size=1) for i in range(depth) ],
             nn.GELU(), nn.Conv2d(dim, n_token, kernel_size=1)
         )
         self.dec = nn.Sequential(
@@ -148,7 +150,7 @@ class Tokenizer2d(nn.Module):
                     if i%draw_every==0 and i:
                         print(i, loss.item())
                        	self.eval()
-                        drawImage(x)
-                        drawImage(self.dec(self(x)))
+                        drawImage(x[:10])
+                        drawImage(self.dec(self(x[:10])))
                         self.train()
         self.eval()
\ No newline at end of file
